pub struct WindowsCallbackLease { /* private fields */ }Expand description
Non-cloneable ownership proof for one callback accepted before the closing fence.
Implementations
Sourceimpl WindowsCallbackLease
impl WindowsCallbackLease
Sourcepub fn generation(&self) -> SessionGeneration
pub fn generation(&self) -> SessionGeneration
Returns the generation that accepted the callback.
Sourcepub fn accepts_completion(&self, session: &WindowsConnectionSession) -> bool
pub fn accepts_completion(&self, session: &WindowsConnectionSession) -> bool
Checks whether this exact accepted callback may complete against session.