WindowsCallbackQueueMetrics

Struct WindowsCallbackQueueMetrics 

pub struct WindowsCallbackQueueMetrics { /* private fields */ }
Bounded callback-ingress counters for one native connection generation.

Implementations

Source

impl WindowsCallbackQueueMetrics

pub const fn accepted_callbacks(self) -> u64

pub const fn queued_fetch_data(self) -> u64

pub const fn queued_cancel_observations(self) -> u64

pub const fn queued_preflights(self) -> u64

Returns blocking native preflight requests queued for durable product decisions.

pub const fn queued_observations(self) -> u64

Returns completed native filesystem observations queued for reconciliation.

pub const fn fetch_queue_full(self) -> u64

pub const fn cancel_observation_queue_full(self) -> u64

pub const fn preflight_queue_full(self) -> u64

Returns blocking preflight requests failed because the queue was full.

pub const fn observation_queue_full(self) -> u64

Returns completed observations dropped because the queue was full.

pub const fn receiver_disconnected(self) -> u64

pub const fn closing_rejections(self) -> u64

pub const fn invalid_snapshot_rejections(self) -> u64

pub const fn panic_failures(self) -> u64