WindowsFetchDataWatchdogOutcome

Struct WindowsFetchDataWatchdogOutcome 

pub struct WindowsFetchDataWatchdogOutcome { /* private fields */ }
Result of one host watchdog poll.

Implementations

Source

impl WindowsFetchDataWatchdogOutcome

pub const fn cancelled(self) -> usize

Returns waiters whose cancellation won the core terminal race.

pub const fn already_cancelled(self) -> usize

Returns waiters that were already cancelled before this poll.

pub const fn already_completed(self) -> usize

Returns waiters that completed before the watchdog cancellation.