pub struct WindowsPreflightRequest { /* private fields */ }Expand description
Accepted preflight request with exactly one native acknowledgement responsibility.
Implementations
Sourceimpl WindowsPreflightRequest
impl WindowsPreflightRequest
Sourcepub const fn snapshot(&self) -> &WindowsPreflightSnapshot
pub const fn snapshot(&self) -> &WindowsPreflightSnapshot
Returns the immutable preflight snapshot.
Sourcepub const fn lease(&self) -> &WindowsCallbackLease
pub const fn lease(&self) -> &WindowsCallbackLease
Returns the accepted generation lease.
Sourcepub const fn acknowledged(&self) -> bool
pub const fn acknowledged(&self) -> bool
Returns whether this request has already attempted its native acknowledgement.