pub struct WindowsFetchDataCancellationOutcome { /* private fields */ }Expand description
Per-callback result of matching one CFAPI cancellation range to active hydration waiters.
Implementations
Sourceimpl WindowsFetchDataCancellationOutcome
impl WindowsFetchDataCancellationOutcome
Sourcepub const fn fully_matched(self) -> usize
pub const fn fully_matched(self) -> usize
Returns waiters whose complete range was covered by the callback range.
Sourcepub const fn partially_matched(self) -> usize
pub const fn partially_matched(self) -> usize
Returns waiters retained because only part of their range was cancelled.
Sourcepub const fn cancelled(self) -> usize
pub const fn cancelled(self) -> usize
Returns full-range cancellations that won the core waiter terminal race.
Sourcepub const fn already_cancelled(self) -> usize
pub const fn already_cancelled(self) -> usize
Returns full-range cancellations already applied to the same active waiter.
Sourcepub const fn already_completed(self) -> usize
pub const fn already_completed(self) -> usize
Returns full-range cancellations that arrived after waiter completion won.