pub struct WindowsFetchDataFlags(/* private fields */);Expand description
Bitset copied from CF_CALLBACK_FETCH_DATA_FLAGS.
Implementations
Sourceimpl WindowsFetchDataFlags
impl WindowsFetchDataFlags
Sourcepub const RECOVERY: Self
pub const RECOVERY: Self
Recovery of a hydration interrupted by an unclean provider or system shutdown.
Sourcepub const EXPLICIT_HYDRATION: Self
pub const EXPLICIT_HYDRATION: Self
Hydration was explicitly initiated rather than caused by ordinary file I/O.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Preserves the exact native bitset, including future bits.