pub struct WindowsFetchDataProgress { /* private fields */ }Expand description
One provider progress sample for a pending CFAPI transfer.
Implementations
Sourceimpl WindowsFetchDataProgress
impl WindowsFetchDataProgress
Sourcepub fn new(total: u64, completed: u64) -> Result<Self>
pub fn new(total: u64, completed: u64) -> Result<Self>
Creates a progress sample. Zero-sized work is represented as (0, 0).
Errors
Returns an error when validation fails or an underlying backend, store, or platform operation fails.
Sourcepub const fn as_cfapi(self) -> (i64, i64)
pub const fn as_cfapi(self) -> (i64, i64)
Returns the signed values accepted by CfReportProviderProgress.
Sourcepub fn advance_from(self, previous: Self) -> Result<Self>
pub fn advance_from(self, previous: Self) -> Result<Self>
Validates a new sample against a previous sample for the same transfer.
Errors
Returns an error when validation fails or an underlying backend, store, or platform operation fails.