pub struct WindowsFetchDataSnapshot { /* private fields */ }Expand description
Owned FETCH_DATA callback snapshot.
Implementations
Sourceimpl WindowsFetchDataSnapshot
impl WindowsFetchDataSnapshot
Sourcepub const fn new(
info: WindowsCallbackInfoSnapshot,
flags: WindowsFetchDataFlags,
required_range: WindowsCallbackRange,
optional_range: Option<WindowsCallbackRange>,
last_dehydration_time: i64,
last_dehydration_reason: u32,
) -> Self
pub const fn new( info: WindowsCallbackInfoSnapshot, flags: WindowsFetchDataFlags, required_range: WindowsCallbackRange, optional_range: Option<WindowsCallbackRange>, last_dehydration_time: i64, last_dehydration_reason: u32, ) -> Self
Creates an owned fetch snapshot after native pointers have been copied.
Sourcepub const fn info(&self) -> &WindowsCallbackInfoSnapshot
pub const fn info(&self) -> &WindowsCallbackInfoSnapshot
Returns common owned callback information.
Sourcepub const fn flags(&self) -> WindowsFetchDataFlags
pub const fn flags(&self) -> WindowsFetchDataFlags
Returns native fetch flags.
Sourcepub const fn is_recovery(&self) -> bool
pub const fn is_recovery(&self) -> bool
Returns whether CFAPI is recovering hydration interrupted by an unclean provider or system
shutdown. Products should reconcile their durable content/cache state before selecting the
revision passed to hydrate or restart_hydration.
Sourcepub const fn required_range(&self) -> WindowsCallbackRange
pub const fn required_range(&self) -> WindowsCallbackRange
Returns the range required to satisfy outstanding I/O.
Sourcepub const fn optional_range(&self) -> Option<WindowsCallbackRange>
pub const fn optional_range(&self) -> Option<WindowsCallbackRange>
Returns the optional broader hydration hint.
Sourcepub const fn last_dehydration_time(&self) -> i64
pub const fn last_dehydration_time(&self) -> i64
Returns the native last-dehydration timestamp.
Sourcepub const fn last_dehydration_reason(&self) -> u32
pub const fn last_dehydration_reason(&self) -> u32
Returns the exact native last-dehydration reason bits.