pub struct WindowsFetchDataTransfer { /* private fields */ }Expand description
Owned logical bytes ready for one synchronous CFAPI transfer call.
Implementations
Sourceimpl WindowsFetchDataTransfer
impl WindowsFetchDataTransfer
Sourcepub fn from_response(
snapshot: &WindowsFetchDataSnapshot,
revision: &ContentRevision,
response: ContentReadResponse,
) -> Result<Self>
pub fn from_response( snapshot: &WindowsFetchDataSnapshot, revision: &ContentRevision, response: ContentReadResponse, ) -> Result<Self>
Validates that a core response exactly satisfies the native required range.
Errors
Returns an error when validation fails or an underlying backend, store, or platform operation fails.