pub struct WindowsFetchDataWatchdogOutcome { /* private fields */ }Expand description
Result of one host watchdog poll.
Implementations
Sourceimpl WindowsFetchDataWatchdogOutcome
impl WindowsFetchDataWatchdogOutcome
Sourcepub const fn cancelled(self) -> usize
pub const fn cancelled(self) -> usize
Returns waiters whose cancellation won the core terminal race.
Sourcepub const fn already_cancelled(self) -> usize
pub const fn already_cancelled(self) -> usize
Returns waiters that were already cancelled before this poll.
Sourcepub const fn already_completed(self) -> usize
pub const fn already_completed(self) -> usize
Returns waiters that completed before the watchdog cancellation.