pub struct WindowsPlaceholderMetadata { /* private fields */ }Expand description
Owned CFAPI filesystem metadata for one placeholder.
Implementations
Sourceimpl WindowsPlaceholderMetadata
impl WindowsPlaceholderMetadata
Sourcepub fn from_item(item: &CloudItem, times: WindowsFileTimes) -> Result<Self>
pub fn from_item(item: &CloudItem, times: WindowsFileTimes) -> Result<Self>
Maps one core item into minimal Windows filesystem metadata.
Errors
Returns an error when validation fails or an underlying backend, store, or platform operation fails.
Sourcepub const fn file_attributes(&self) -> u32
pub const fn file_attributes(&self) -> u32
Returns Windows file-attribute bits.
Sourcepub const fn times(&self) -> WindowsFileTimes
pub const fn times(&self) -> WindowsFileTimes
Returns all Windows file times.